@@ -106,11 +106,14 @@ class quantim:
             resp = {'msg':'Check permissions!'}
         return resp['msg']
 
-    def upload_with_presigned_url(self, local_file_path, bucket, key):
+    def upload_with_presigned_url(self, local_file_path, bucket, key, prefix=None):
         """
         Upload a local file to S3 using a presigned URL.
         """
-        data = {'bucket':bucket, 'key':key}
+        if prefix:
+            data = {'bucket':bucket, 'key':key, 'prefix':prefix}
+        else:
+            data = {'bucket':bucket, 'key':key, 'prefix':key}
         try:
             presigned_url = self.api_call('link_data_s3', method="post", data=data, verify=False)
         except Exception as e:
