@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
+import re
 import pandas as pd
 import numpy as np
 import datetime as dt
+import requests, io
 from dateutil.relativedelta import relativedelta as rd
 from .api import quantim
 from .utils import generate_unique_id, generate_timestamp
@@ -232,8 +234,11 @@ class risk_data(quantim):
         data = {'ref_date':ref_date, 'return_cfs':return_cfs}
         resp = self.api_call('irl', method="post", data=data, verify=False)
         irl_report = pd.DataFrame(resp['irl'])
-        cfs = pd.read_csv(resp['cf_url']) if return_cfs else None
-
+        cfs = None
+        # cfs_bkup = pd.read_csv(resp['cf_url']) if return_cfs else None
+        if return_cfs:
+            irl_cfs = requests.get(resp['cf_url'], verify=False)
+            cfs = pd.read_csv(io.StringIO(irl_cfs.content.decode('utf-8-sig')), sep=',')
         return irl_report, cfs
 
     def load_series_cl(self, file_path_performance=None, file_path_peers=None):
@@ -320,3 +325,49 @@ class risk_data(quantim):
             print("Archivo no disponible")
             return None
         return df
+
+    def load_positions(self, file_path):
+        '''
+        Load positions.
+        '''
+        # Load data
+        filename = file_path.split("/")[-1]
+        # validar el nombre del archivo
+        patron = r"^Positions_(\d{8})\.csv$"
+        match = re.match(patron, filename)
+        if not match:
+            raise ValueError('You can only update files named Positions_YYYYMMDD.csv. Please check.')
+        # validar que la fecha sea valida
+        fecha_str = match.group(1)
+        try:
+            dt.datetime.strptime(fecha_str, "%Y%m%d")
+        except ValueError:
+            raise ValueError('The date is not valid.')
+        prefix="inputs/portfolios/CO/Positions_"
+        key= f"inputs/portfolios/CO/{filename}"
+        bucket="condor-sura"
+        resp = self.upload_with_presigned_url(file_path, bucket, key, prefix)
+        return resp
+    
+    def load_haircuts(self, file_path):
+        '''
+        Load haircuts banrep.
+        '''
+        # Load data
+        filename = file_path.split("/")[-1]
+        # validar el nombre del archivo
+        patron = r"^haircuts_(\d{6})\.xlsx$"
+        match = re.match(patron, filename)
+        if not match:
+            raise ValueError('You can only update files named haircuts_YYYYMM.xlsx. Please check.')
+        # validar que la fecha sea valida
+        fecha_str = match.group(1)
+        try:
+            dt.datetime.strptime(fecha_str, "%Y%m")
+        except ValueError:
+            raise ValueError('The date is not valid. Format must be YYYYMM')
+        prefix="inputs/risk/varliquid/haircuts/haircuts_"
+        key= f"inputs/risk/varliquid/haircuts/{filename}"
+        bucket="condor-sura"
+        resp = self.upload_with_presigned_url(file_path, bucket, key, prefix)
+        return resp
\ No newline at end of file
